@@ -59,8 +59,7 @@ from dagster_airbyte.utils import _get_attempt, generate_materializations
     tags={"kind": "airbyte"},
 )
 def airbyte_sync_op(context):
-    """
-    Executes a Airbyte job sync for a given ``connection_id``, and polls until that sync
+    """Executes a Airbyte job sync for a given ``connection_id``, and polls until that sync
     completes, raising an error if it is unsuccessful. It outputs a AirbyteOutput which contains
     the job details for a given ``connection_id``.
 
